#slc-linkcollection-linkbox {
    border: 1px solid rgb(203, 209, 216); 
    padding: 5px; 
    background-color: rgb(247, 248, 249); 
    margin-bottom: 10px;
    
}
#slc-linkcollection-editbox {
    padding: 3px; float: right;
}
.current-linklist-item {
    font-weight: bold;
}